********************************************************************************
*** Analysen zu Buchbeitrag "Was macht den Unterschied? Ein Vergleich von    *** 
*** von Bildungsaufsteigern und Nichtaufsteigern"                            ***
***                                                                          ***
*** MASTER                                                                   ***
*** Steffen Schindler, 01.03.2019                                            *** 
********************************************************************************

clear
set more off

global data   "[Pfad für Speicherort der NEPS-Daten einfügen]"
global dofile "[Pfad für Speicherort der Dofiles einfügen]" 
global save   "[Pfad für Speicherort der zu generierenden Datensätze und Outputs einfügen]"

*** Schulform in Welle 7 (2017) ************************************************
clear
set more off
cd "$data"
use "SC2_spParentSchool_D_7-0-0.dta"
cd "$dofile"
do schulform.do
keep ID_t schulform
cd "$save"
save schulform.dta, replace

*** Bildung der Eltern *********************************************************
clear
set more off
cd "$data"
use "SC2_pParent_D_7-0-0.dta"
cd "$dofile"
do bilelt.do
keep ID_t bilelt
cd "$save"
save bilelt.dta, replace

*** Bildungsaufstieg ***********************************************************
clear
set more off
cd "$save"
use "bilelt.dta"
merge 1:1 ID_t using schulform.dta
keep if _merge==3
drop _merge
cd "$dofile"
do bildauf.do
cd "$save"
save bildauf.dta, replace

*** Prädiktoren (Eltern) *******************************************************
clear
set more off
cd "$data"
use "SC2_pParent_D_7-0-0.dta"
cd "$dofile"
do uveltern.do
keep if n==1
keep ID_t eink eink_k allein buch kultbesitz kultpart kultkap haustaet monitor ///
     geschwister eltschul ausaktiv sigpers aspabi wskabi esprache isprache ///
	 abikost_l abikost_s isei sig_verw sig_freu sig_freuf sig_verws sig_freus geschl
cd "$save"
save uveltern.dta, replace

*** Prädiktoren (Zielperson/Kind) **********************************************
clear
set more off
cd "$data"
use "SC2_pTarget_D_7-0-0.dta"
cd "$dofile"
do uvperson.do
bys ID_t: gen n=_n
keep if n==1
keep ID_t lernfreu anstreng buchkenn monitor_k note b5_neuro b5_offen b5_vertr b5_gewis b5_extra
cd "$save"
save uvperson.dta, replace

*** Prädiktoren (Kompetenzen) **************************************************
clear
set more off
cd "$data"
use "SC2_xTargetCompetencies_D_7-0-0.dta"
cd "$dofile"
do uvkomp.do
keep ID_t wortschatz grammatik mathe natur kompscore prozmeta  
cd "$save"
save uvkomp.dta, replace

*** Prädiktoren (Merkmale der Schulklasse) *************************************
clear
set more off
cd "$data"
use "SC2_pCourseClass_D_7-0-0.dta"
cd "$dofile"
do uvklasse.do
keep if wave==3
bys ID_cc: gen n=_n
keep if n==1
keep ID_cc wave migant schuelerzahl klsprache klnatur klmathe leisthomo leistorie foerder foerder_k klscore hoschi mischi nischi elthoschu 
cd "$save"
save uvklasse.dta, replace

*** Gewicht ********************************************************************
clear
set more off
cd "$data"
use "SC2_WeightsElementarySchool_D_7-0-0.dta"
keep ID_t w_t7
cd "$save"
save gewicht.dta, replace

*** Zusammenfügen der Datensätze ***********************************************
clear 
set more off
cd "$data"
use "SC2_CohortProfile_D_7-0-0.dta"
keep ID_t wave ID_cc
cd "$save"

* Klassen-ID in Wellen 3-6 (Klassen 1-4)
foreach num of numlist 3/6{
   gen ID_cc`num'=ID_cc if wave==`num'
   replace ID_cc`num'=. if ID_cc`num'==-55
   }

* Merkmale der Schulklassen
merge m:1 ID_cc using uvklasse.dta, gen(m_uvklasse) 
foreach var of varlist ID_cc3-ID_cc6 migant- elthoschu{
   replace `var'=. if wave!=3
   bys ID_t: egen temp=max(`var')
   replace `var'=temp
   drop temp
   }
bys ID_t: gen n=_n
keep if n==1
drop n wave ID_cc

* Bildungsaufstieg
merge 1:1 ID_t using bildauf.dta, gen(m_bildauf) 

* Prädiktoren (Eltern)
merge 1:1 ID_t using uveltern.dta, gen(m_uveltern) 

* Prädiktoren (Zielperson/Kind)
merge 1:1 ID_t using uvperson.dta, gen(m_uvperson) 

* Prädiktoren (Kompetenzen)
merge 1:1 ID_t using uvkomp.dta, gen(m_uvkomp) 

* Gewicht
merge 1:1 ID_t using gewicht.dta, gen(m_gewicht) 

* speichern
cd "$save"
compress
save complete.dta, replace

*** Prädiktoren (Merkmale der Schulklasse, generiert aus Individualdaten) ******
clear
set more off
cd "$save"
use "complete.dta"
cd "$dofile"
do uvklasse_g.do
cd "$save"
save complete_g.dta, replace
