********************************************************************************
*** Analysen zu Buchbeitrag "Was macht den Unterschied? Ein Vergleich von    *** 
*** von Bildungsaufsteigern und Nichtaufsteigern"                            ***
***                                                                          ***
*** Multivariate Analysen                                                    ***
*** Steffen Schindler, 01.03.2019                                            *** 
********************************************************************************


********************************************************************************
*** Datensatz laden ************************************************************
********************************************************************************

cd "$save"
use "complete_g.dta", clear


********************************************************************************
*** Analysenspezifische Recodes ************************************************
********************************************************************************

*** niedriges Einkommen binär
recode eink_k (1=1 "<2000") (2 3=0 ">=2000") (else=.), into(eink_bi)

*** Signifikante Personen binär kodieren: jeweils mehr als die Hälfte
foreach var of varlist sig_verw sig_freu sig_freuf{
   recode `var' (1/3=0) (4/5=1), into(`var'_bi)
   }
foreach var of varlist sig_verws sig_freus{
   recode `var' (1/4=0) (5/7=1), into(`var'_bi)
   }
*
*** Dummies aus Geschwisteranzahl
tab geschwister, gen(geschw)   


********************************************************************************
*** Globals ********************************************************************
********************************************************************************

*** Gewicht ***
global gew=1  // w_t7

global note note // Schulnote in Klasse 4
global controls geschl esprache geschw2 geschw3 geschw4 // Geschlecht, Herkunftssprache Eltern nicht Deutsch
global komp kompscore prozmeta // Kompetenzen
global b5 b5_* // Big Five
global kultkap kultkap // kulturelles Kapital
global sozkap1 eltschul // innerfamiliäres Sozialkapital
global sozkap2 sig_freuf_bi sig_verws_bi sig_freus_bi // außerfamiliäres Sozialkapital
global oekkap eink_bi // ökonomisches Kapital
global asp aspabi // Aspirationen
global risiko wskabi // Risikowahrnehmung
global kontext kl_aspabi // Lernkontext


********************************************************************************
*** Schulnoten in der 4. Klasse ************************************************
********************************************************************************

qui reg note bildauf $controls $komp $kultkap $sozkap1 $sozkap2 $oekkap $asp $kontext $b5 [aw=$gew], cluster(ID_cc3)
gen sample=e(sample)

* OLS-Regression
reg note bildauf [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n0
reg note bildauf $controls [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n1
reg note bildauf $controls $komp [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n2
reg note bildauf $controls $komp [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n3
reg note bildauf $controls $komp $kultkap [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n4
reg note bildauf $controls $komp $kultkap $sozkap1 [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n5
reg note bildauf $controls $komp $kultkap $sozkap1 $sozkap2 [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n6
reg note bildauf $controls $komp $kultkap $sozkap1 $sozkap2 $oekkap [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n7
reg note bildauf $controls $komp $kultkap $sozkap1 $sozkap2 $oekkap $asp [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n8
reg note bildauf $controls $komp $kultkap $sozkap1 $sozkap2 $oekkap $asp $kontext [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n9
reg note bildauf $controls $komp $kultkap $sozkap1 $sozkap2 $oekkap $asp $kontext $b5 [aw=$gew] if sample==1, cluster(ID_cc3)
eststo n10

cd "$save"
esttab n0 n1 n2 n3 n4 n5 n6 n7 n8 n9 n10 using noten.csv, b(2) r2 replace

* Blinder-Oaxaca-Effektdekomposition
oaxaca note (controls: geschl esprache normalize(geschw1 geschw2 geschw3 geschw4)) (komp: $komp) (kultkap: $kultkap) (sozkap: $sozkap1 $sozkap2) (oekkap: $oekkap) (asp: $asp) (kontext: $kontext) (B5: $b5) [aw=$gew], by(bildauf) pooled
oaxaca note  geschl esprache normalize(geschw1 geschw2 geschw3 geschw4) $komp $kultkap $sozkap1 $sozkap2 $oekkap $asp $kontext $b5 [aw=$gew], by(bildauf) pooled


********************************************************************************
*** Bildungsaufstieg ***********************************************************
********************************************************************************

* OLS-Regression
logit bildauf $controls [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m0
logit bildauf $controls $note [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m1
logit bildauf $controls $note $komp [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m2
logit bildauf $controls $note $komp $kultkap [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m3
logit bildauf $controls $note $komp $kultkap $sozkap1 [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m4
logit bildauf $controls $note $komp $kultkap $sozkap1 $sozkap2 [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m5
logit bildauf $controls $note $komp $kultkap $sozkap1 $sozkap2 $oekkap [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m6
logit bildauf $controls $note $komp $kultkap $sozkap1 $sozkap2 $oekkap $asp [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m7
logit bildauf $controls $note $komp $kultkap $sozkap1 $sozkap2 $oekkap $asp $kontext [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m8
logit bildauf $controls $note $komp $kultkap $sozkap1 $sozkap2 $oekkap $asp $kontext $b5 [pw=$gew] if sample==1, cluster(ID_cc3)
eststo m9

cd "$save"
esttab m0 m1 m2 m3 m4 m5 m6 m7 m8 m9 using bildauf.csv, b(2) replace pr2


********************************************************************************
*** ergänzende Analysen ********************************************************
********************************************************************************

*** Regression B5-Offenheit auf Ressourcen Aspirationen/Risikowahrnehmung und Kontexte ***
reg b5_offen eink_k allein abikost_l kultbesitz kultpart haustaet buchkenn ///
    monitor monitor_k geschwister eltschul ausaktiv /// 
	sig_verw_bi sig_freu_bi sig_freuf_bi sig_verws_bi sig_freus_bi ///
	aspabi wskabi $komp ///
	kl_kompscore kl_esprache kl_eltho kl_aspabi [pw=$gew] if bildauf!=., cluster(ID_cc3)
eststo z1


*** Regression Aspirationen auf Ressourcen, B5, Risikowahrnehmung und Kontexte ***
reg aspabi eink_k allein abikost_l kultbesitz kultpart haustaet buchkenn ///
    monitor monitor_k geschwister eltschul ausaktiv /// 
	sig_verw_bi sig_freu_bi sig_freuf_bi sig_verws_bi sig_freus_bi ///
	b5_* wskabi $komp ///
	kl_kompscore kl_esprache kl_eltho kl_aspabi [pw=$gew] if bildauf!=., cluster(ID_cc3)
eststo z2

cd "$save"
esttab z1 z2
esttab z1 z2 using zusatz_aspabi.csv, b(2) replace pr2











