********************************************************************************
*** Analysen zu Buchbeitrag "Was macht den Unterschied? Ein Vergleich von    *** 
*** von Bildungsaufsteigern und Nichtaufsteigern"                            ***
***                                                                          ***
*** UNABHÄNGIGE VARIABLEN (ELTERNANGABEN)                                    ***
*** Steffen Schindler, 01.03.2019                                            *** 
********************************************************************************

********************************************************************************
*** Geschlecht Kind ************************************************************
********************************************************************************
bys ID_t: egen geschl=mode(p700010), minmode
recode geschl 1=0 2=1
lab def geschl 0 "Junge" 1 "Mädchen"
lab val geschl geschl
lab var geschl "Geschlecht"


********************************************************************************
*** Ökonomische Ressourcen *****************************************************
********************************************************************************

*** Einkommen ***

*** Netto-Haushaltseinkommen liegt unter 2500 EUR
recode p510005 (0/2000=1 "<2500") (2501/500000=0 ">2500") (else=.), into(eink_)
replace eink_=1 if eink_==. & (inrange(p510007,1,3)| p510008==4) 

*** Netto-Haushaltseinkommen liegt in mind. 33% der Wellen mit Einkommensangaben unter 2500 EUR
* Anzahl der Wellen imt Angaben zum Einkommen
bys ID_t: egen eink1=count(eink_)
* Anzahl der Wellen mit niedrigem Einkommen
bys ID_t: egen eink2=sum(eink_)
* Anteil mit niedrigem Einkommen >33%
gen eink=eink2/eink1
recode eink 0/0.33=0 0.33/1=1
* ACHTUNG: Missings werden auf null gesetzt, um Fallzahlen nicht zu reduzieren
* dies kann vermutlich zur Unterschätzung des Effekts geringer Einkommen führen
replace eink=0 if eink==. 
lab var eink "niedriges Haushaltseinkommen"

*** Einkommenskategorien
recode p510005 (0/1999=1) (2000/3999=2) (4000/max=3) (else=.), into(eink_k1)
replace eink_k1=1 if eink_k1==. & p510006==1
replace eink_k1=2 if eink_k1==. & p510006==2
replace eink_k1=3 if eink_k1==. & p510006==3

*** Median-Einkommenskategorie über Wellen 2-6
replace eink_k1=. if wave==7
bys ID_t: egen eink_k=median(eink_k1)
* bei uneindeutigen Medianwerten abrunden:
replace eink_k=floor(eink_k) 
lab def eink_k 1 "unter 2000 EUR" ///
			   2 "2000 bis unter 4000 EUR" ///
			   3 "4000 EUR und mehr"
lab val eink_k eink_k
lab var eink_k "Netto-Haushaltseinkommen kategorial"
			   

*** Alleinerziehend ***
recode p731111 (1=0 "nein") (2=1 "ja") (else=.), into(allein_)

*** mind. in 33% der Wellen mit Angaben alleinerziehend
* Anzahl der Wellen mit Angaben zum Alleinerziehenden-Status
bys ID_t: egen allein1=count(allein_)
* Anzahl der Wellen alleinerziehend
bys ID_t: egen allein2=sum(allein_)
* Anteil alleinerziehend >33%
gen allein=allein2/allein1
recode allein 0/0.33=0 0.33/1=1
lab var allein "alleinerziehend" 
* ACHTUNG: Missings werden auf null gesetzt, um Fallzahlen nicht zu reduzieren
* dies kann vermutlich zur Unterschätzung des Effekts alleinerziehender führen
replace allein=0 if allein==. 

*** finanzielle Belastung Abitur ***
* Und wie schwer würde es Ihnen fallen, diese Kosten zu übernehmen, wenn ... das Abitur machen würde?
* Es werden zwei dichotome Varianten rekodiert: 1) sehr leicht+eher leicht 2) sehr schwer+eher schwer
* ACHTUNG: Missings werden auf null gesetzt, um Fallzahlen nicht zu reduzieren
* dies kann vermutlich zur Unterschätzung des Effekts alleinerziehender führen
* Welle 5 (2015)

recode p30335c (4 5=1 "fällt leicht") (else=0 "fällt nicht leicht") if wave==5, into(abikost_l)
bys ID_t: egen temp=max(abikost_l)
replace abikost_l=temp
drop temp
lab var abikost_l "Abikosten tragen fällt leicht (W5)"

recode p30335c (1 2=1 "fällt schwer") (else=0 "fällt nicht schwer") if wave==5, into(abikost_s)
bys ID_t: egen temp=max(abikost_s)
replace abikost_s=temp
drop temp
lab var abikost_s "Abikosten tragen fällt schwer (W5)"


********************************************************************************
*** Kulturelle Ressourcen ******************************************************
********************************************************************************

*** kulturelles Kapital ********************************************************

*** Anzahl Bücher
* Anzahl Bücher basiert auf durchschnittlicher Angabe aus drei Wellen
* Angaben zu ebooks werden nicht verwendet, da nur in Welle 6 erhoben
replace p34005a=. if p34005a<1
bys ID_t: egen buch=mean(p34005a)
replace buch=round(buch)
lab val buch de176
lab var buch "Anzahl Bücher"

*** Besitz Kulturgut
* Index: Besitz von klassischer Literatur, Kunstwerke, Bibliotheksausweis, Wörterbuch, Gedichtbände
gen kultbesitz=0
lab var kultbesitz "Besitz von Kulturgut"
foreach var of varlist p34006d p34006e p34006f p34006h p34006j{ 
   replace `var'=. if `var'<0
   bys ID_t: egen `var'_m=mean(`var')
   replace `var'_m=round(`var'_m)
   replace kultbesitz=kultbesitz+1 if `var'_m==1
   }

*** Partizipation an Hochkultur
* Index: Aktivitäten Museum, Kino, Oper/Ballett/Konzert, Theater, Rock/Popkonzert
foreach var of varlist p34009a p34009b p34009c p34009d p34009e { 
   replace `var'=. if `var'<0
   bys ID_t: egen `var'_m=mean(`var')
   replace `var'_m=round(`var'_m)
   }   
egen kultpart=rowmean(p34009a_m p34009b_m p34009c_m p34009d_m p34009e_m)
lab var kultpart "Partizipation an Hochkultur"   

*** Index kulturelles Kapital
* Variablen: Anzahl Bücher, Besitz Kulturgut, Partizipation an Hochkultur
* Erstellung Score: Aufaddieren der kumulativen Häufigkeiten der jeweils individuell vorliegenden Kategorien
bys ID_t (wave): gen n=_n
foreach var of varlist buch kultbesitz kultpart{
   levelsof `var', local(lev)
   gen `var'_cum=.
   foreach num of local lev{
      tab `var' if n==1
	  local n=r(N)
	  tab `var' if n==1 & `var'<=`num'
	  local m=r(N)
	  replace `var'_cum=`m'/`n' if `var'==`num'     
      }
   }
egen kultkap=rowmean(buch_cum kultbesitz_cum kultpart_cum)
lab var kultkap "Score kulturelles Kapital"


*** schulnahe Tätigkeiten zu Hause *********************************************

* Tätigkeiten: Vorlesen, Geschichten erzählen, Musizieren, Malen, Sport, Spielen, Spielplatz
* Häufigkeit: nie, seltener, einmal im Monat, mehrmals im Monat, einmal in der Woche, mehrmals in der Woche, einmal täglich, mehrmals täglich
* Erstellung Score: Aufaddieren der kumulativen Häufigkeiten der jeweils individuell vorliegenden Kategorien
* Welle 3 (2013)
foreach var of varlist p281361 p281372 p281374 p281365 p281377 p281378 p281379{
   gen `var'_cum=.
   recode `var' (8=1 "nie") (7=2 "seltener") (6=3 "einmal im Monat") (5=4 "mehrmals im Monat") (4=5 "einmal in der Woche") (3=6 "mehrmals in der Woche") (2=7 "einmal täglich") (1=8 "mehrmals täglich") (else=.) if wave==3, into(`var'_m)
   foreach num of numlist 1/8{
      tab `var'_m if wave==3
	  local n=r(N)
	  tab `var'_m if wave==3 & `var'_m<=`num'
	  local m=r(N)
	  replace `var'_cum=`m'/`n' if `var'_m==`num'
	  }
   }  
egen haustaet=rowmean(p281361_cum p281372_cum p281374_cum p281365_cum p281377_cum p281378_cum p281379_cum)
bys ID_t: egen temp=max(haustaet)
replace haustaet=temp
drop temp
lab var haustaet "Score Häufigkeit schulnaher Tätigeiten zu Hause (W3)"


********************************************************************************
*** Soziale Ressourcen *********************************************************
********************************************************************************

*** Eltern-Kind-Beziehungen ****************************************************

*** Parental Monitoring ***

* Erzählen: "wie häufig erzählt Ihnen ... von..."
* Fragen: "wie häufig fragen Sie nach..."
* Kategorien: allgemein Schule, Lehrer zurechtkommen, Kinder zurechtkommen, Hausaufgaben, Freunde
* Erstellung Score: Aufaddieren der kumulativen Häufigkeiten der jeweils individuell vorliegenden Kategorien
* Welle 5 (2015)
foreach var of varlist p282801 p282802 p282803 p282804 p282806 p282811 p282812 p282813 p282814 p282816{
   gen `var'_cum=.
   replace `var'=. if `var'<1
   foreach num of numlist 1/5{
      tab `var' if wave==5
	  local n=r(N)
	  tab `var' if wave==5 & `var'<=`num'
	  local m=r(N)
	  replace `var'_cum=`m'/`n' if `var'==`num'
	  }
   }  
egen monitor=rowmean(p282801_cum p282802_cum p282803_cum p282804_cum p282806_cum p282811_cum p282812_cum p282813_cum p282814_cum p282816_cum)
bys ID_t: egen temp=max(monitor)
replace monitor=temp
drop temp
lab var monitor "Score parental monitoring (Eltern W5)"

*** Anzahl der Geschwister im Haushalt ***

* Welle 4 (2014)
recode p732104 (0=0 "keine Geschwister") (1=1 "1 Geschwister") (2=2 "2 Geschwister") (3/9=3 "3 oder merhr Geschwister") (else=.) if wave==4, into(geschwister)
bys ID_t: egen temp=max(geschwister)
replace geschwister=temp
drop temp
lab var geschwister "Anzahl Geschwister im Haushalt (W4)"


*** Soziale Beziehungen außerhalb der Kernfamilie ******************************

*** Schulische Einbindung der Eltern ***

* Kategorien: Elternabende, Gespräche mit Lehrkräften, Elternbeirat, Veranstaltungen 
* Welle 4 (2014)
foreach var of varlist p32903a p32903b p32903c p32903d{
   gen `var'_cum=.
   replace `var'=. if `var'<1
   foreach num of numlist 1/5{
      tab `var' if wave==4
	  local n=r(N)
	  tab `var' if wave==4 & `var'<=`num'
	  local m=r(N)
	  replace `var'_cum=`m'/`n' if `var'==`num'
	  }
   }  
egen eltschul=rowmean(p32903a_cum p32903b_cum p32903c_cum p32903d_cum)
bys ID_t: egen temp=max(eltschul)
replace eltschul=temp
drop temp
lab var eltschul "Score schulische Einbindung der Eltern"

*** außerhäusliche Aktivitäten ***

* Stunden in außerhäußlichen Tätigkeiten pro Woche 
* Sport, Musik, Sprachkurse, sonstiges
* Welle 4 (2014)

recode p261600 (-98 -54=.) (30/90=30), copyrest into(ausaktiv)
bys ID_t: egen temp=max(ausaktiv)
replace ausaktiv=temp
drop temp
lab var ausaktiv "Wochenstunden außerhäusliche Aktivitäten"

*** signifikante Personen ***

* Personengruppen: Verwandte, Freunde
* Dimensionen:
* Meine Verwandten/Freunde interessieren sich dafür, wie es bei ... in der Schule läuft
* Anteil Verwandte/Freunde mit Studium
* Meine Freundinnen und Freunde erwarten von mir, dass ich ... so gut wie möglich fördere
* Kategorien: trifft gar nicht zu, trifft eher nicht zu, teils/teils, trifft eher zu, trifft voll und ganz zu
* Erstellung Score: Aufaddieren der kumulativen Häufigkeiten der jeweils individuell vorliegenden Kategorien
* Welle 4 (2014)
foreach var of varlist p320660 p321604 p320160 p321104 p320107{
   replace `var'=1 if `var'==-21
   replace `var'=. if `var'<1
   levelsof `var', local(lev)
   gen `var'_cum=.
   foreach num of local lev{
      tab `var' if wave==4
	  local n=r(N)
	  tab `var' if wave==4 & `var'<=`num'
	  local m=r(N)
	  replace `var'_cum=`m'/`n' if `var'==`num'     
      }
   }
egen sigpers=rowmean(p320660_cum p321604_cum p320160_cum p321104_cum p320107_cum) 
bys ID_t: egen temp=max(sigpers)
replace sigpers=temp
drop temp
lab var sigpers "Score signifikante Personen"   


*** Signifikante Personen Einzelitems ***

* Verwandte interessieren sich
replace p320660=. if p320660<1
ren p320660 sig_verw
bys ID_t: egen temp=max(sig_verw)
replace sig_verw=temp
drop temp

* Freunde interessieren sich
replace p320160=. if p320160<1
ren p320160 sig_freu
bys ID_t: egen temp=max(sig_freu)
replace sig_freu=temp
drop temp

* Freunde erwarten Förderung des Kindes
replace p320107=. if p320107<1
ren p320107 sig_freuf
bys ID_t: egen temp=max(sig_freuf)
replace sig_freuf=temp
drop temp

* Anteil Verwandte mit Studium
replace p321604=. if p321604<1
ren p321604 sig_verws
bys ID_t: egen temp=max(sig_verws)
replace sig_verws=temp
drop temp

* Anteil Freunde mit Studium
replace p321104=. if p321104<1
ren p321104 sig_freus
bys ID_t: egen temp=max(sig_freus)
replace sig_freus=temp
drop temp





********************************************************************************
*** Bildungsaspirationen *******************************************************
********************************************************************************
   
* Aspiration für Abitur zu Beginn der Grundschule
* Welle 3 (2013)
* ACHTUNG: 71 Missings werden als null rekodiert. Dies kann zu minimaler Unterschätzung des Effekts führen
recode p31035a (4=1 "Abitur") (else=0 "kein Abitur") if wave==3, into(aspabi)
bys ID_t: egen temp=max(aspabi)
replace aspabi=temp
drop temp
lab var aspabi "Aspiration für Abitur (W3)" 


********************************************************************************
*** Risikowahrnehmung **********************************************************
********************************************************************************

* Einschätzung Wahrscheinlichkeit Abitur zu erreichen
* Welle 5 (2015)
* ACHTUNG: 13 Missings werden als null rekodiert. Dies kann zu minimaler Unterschätzung des Effekts führen
recode p30035c (4 5=1 "wahrscheinlich") (else=0 "nicht wahrscheinlich") if wave==5, into(wskabi)
bys ID_t: egen temp=max(wskabi)
replace wskabi=temp
drop temp
lab var wskabi "Einschätzung Wahrscheinlichkeit Abitur (W5)" 


********************************************************************************
*** Kontrollvariablen **********************************************************
********************************************************************************

*** Migrationshintergrund ******************************************************

*** Herkunftssprache Eltern ***
* ACHTUNG: Missings werden als null rekodiert. Dies kann zu Unterschätzung des Effekts führen
gen esprache=0
replace esprache=1 if (p413000_g1D==1 | p414000_g1D==1) & wave==4
replace esprache=1 if (p413000_g1D==1 & p414000_g1D==1) & wave==4
bys ID_t: egen temp=max(esprache)
replace esprache=temp
drop temp
lab var esprache "Herkunftssprache Eltern nicht Deutsch"

*** Interaktionssprache mit Eltern ***
* ACHTUNG: Missings werden als null rekodiert. Dies kann zu Unterschätzung des Effekts führen
gen isprache=0
replace isprache=1 if inlist(p412070,3,4) & inlist(p412080,3,4) & wave==4
bys ID_t: egen temp=max(isprache)
replace isprache=temp
drop temp
lab var isprache "Interaktionssprache mit Eltern nicht Deutsch"


*** Beruflicher Status Eltern **************************************************

*** Höchster ISEI Eltern ***
* durchschnittlicher Status gültiger Werte über alle Wellen
* ISEI-88
replace p731904_g5=. if p731904_g5<16
replace p731954_g5=. if p731954_g5<16
bys ID_t: egen isei1=mean(p731904_g5)
bys ID_t: egen isei2=mean(p731954_g5)
egen isei=rowmax(isei1 isei2)
lab var isei "Höchster ISEI Eltern"









exit


*** alte Recodes ***************************************************************

* kumulierte Quartils-Position auf den drei Indikatoren
tab1 buch kultbesitz kultpart
gen kultindex1=0
gen kultindex2=0
gen kultindex3=0
* Einteilung in Quartile für jeden Indikator:
replace kultindex1=kultindex1+1 if inrange(buch,1,3)
replace kultindex1=kultindex1+2 if inrange(buch,4,4)
replace kultindex1=kultindex1+3 if inrange(buch,5,5)
replace kultindex1=kultindex1+4 if inrange(buch,6,6)
replace kultindex2=kultindex2+1 if inrange(kultbesitz,0,2) 
replace kultindex2=kultindex2+2 if inrange(kultbesitz,3,3) 
replace kultindex2=kultindex2+3 if inrange(kultbesitz,4,4)     
replace kultindex2=kultindex2+4 if inrange(kultbesitz,5,5)    
replace kultindex3=kultindex3+1 if inrange(kultpart,1,1.7)    
replace kultindex3=kultindex3+2 if inrange(kultpart,1.8,2)  
replace kultindex3=kultindex3+3 if inrange(kultpart,2.2,2.6)  
replace kultindex3=kultindex3+4 if inrange(kultpart,2.8,5)
* Quantils-Mittelwert
foreach var of varlist kultindex1 kultindex2 kultindex3{
   replace `var'=. if `var'==0
   }
egen kultindex_m=rowmean(kultindex1 kultindex2 kultindex3)
replace kultindex_m=round(kultindex_m)
* Bei Missings: Ersetzen durch Mittelwert
replace kultindex1=kultindex_m if kultindex1==. & kultindex_m!=.
replace kultindex2=kultindex_m if kultindex2==. & kultindex_m!=.
replace kultindex3=kultindex_m if kultindex3==. & kultindex_m!=.
* Aufaddieren der Quartils-Positionen auf den drei Indikatoren
egen kultindex=rowtotal(kultindex1 kultindex2 kultindex3)
recode kultindex 3/5=1 6/8=2 9/10=3 11/12=4
lab var kultindex "Quartil der Ausstattung mit kulturellem Kapital"




